export declare type Callback<T> = (err: any, result?: T) => void;
export declare type Thunk<T> = (cb: Callback<T>) => void;
export declare let wait: <T = any>(promiseOrCallback: Promise<T> | Thunk<T>) => T;
export declare let run: <T>(fn: () => T) => Promise<T>;
export declare function funnel(max?: number): Funnel;
export interface Funnel {
    <T>(fn: () => T): T;
    close(): void;
}
export declare function handshake<T = void>(): {
    wait(): T;
    notify(): void;
};
export interface Handshake<T = void> {
    wait(): void;
    notify(): void;
}
export interface QueueOptions {
    max?: number;
}
export declare class Queue<T> {
    _max: number;
    _callback: Callback<T> | undefined;
    _err: any;
    _q: (T | undefined)[];
    _pendingWrites: [Callback<T>, T | undefined][];
    constructor(options?: QueueOptions | number);
    read(): T;
    write(item: T | undefined): T;
    put(item: T | undefined, force?: boolean): boolean;
    end(): void;
    peek(): T | undefined;
    contents(): (T | undefined)[];
    adjust(fn: (old: (T | undefined)[]) => (T | undefined)[]): void;
    readonly length: number;
}
export declare function withContext<T>(fn: () => T, cx: any): T;
export declare function context<T = any>(): T;
export declare function map<T, R>(collection: T[], fn: (val: T) => R): R[];
export declare function sleep(n: number): void;
export declare function canWait(): boolean;
export declare function eventHandler<T extends Function>(handler: T): T;
